@@ -2,11 +2,9 @@
 #
 # Drawing - A class for writing the Excel XLSX Drawing file.
 #
-# Copyright 2013-2016, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
-import re
-
 from . import xmlwriter
 from .shape import Shape
 from .utility import get_rgb_color
@@ -315,8 +313,11 @@ class Drawing(xmlwriter.XMLwriter):
 
         self._xml_end_tag('xdr:nvGraphicFramePr')
 
-    def _write_c_nv_pr(self, index, name, options={}):
+    def _write_c_nv_pr(self, index, name, options=None):
         # Write the <xdr:cNvPr> element.
+        if options is None:
+            options = {}
+
         descr = options.get('description', None)
         url = options.get('url', None)
         tip = options.get('tip', None)
@@ -1049,9 +1050,6 @@ class Drawing(xmlwriter.XMLwriter):
     def _write_a_fill_to_rect(self, gradient_type):
         # Write the <a:fillToRect> element.
 
-        l = '100000'
-        t = '100000'
-
         if gradient_type == 'shape':
             attributes = [
                 ('l', '50000'),
